16.21. cdist-type__config_file(7) — cdist 6.9.8 documentation

# 16.21. cdist-type__config_file(7)

## 16.21.1. NAME

cdist-type__config_file - _Manages config files

## 16.21.2. DESCRIPTION

Deploy config files using the file type. Run the given code if the files changes.

## 16.21.3. REQUIRED PARAMETERS

None.

## 16.21.4. OPTIONAL PARAMETERS

group

  see cdist-type__file

mode

  see cdist-type__file

onchange

  the code to run if the file changes

owner

  see cdist-type__file

source

  Path to the config file. If source is '-' (dash), take what was written to stdin as the config file content.

state

  see cdist-type__file

## 16.21.5. EXAMPLES

    __config_file /etc/consul/conf.d/watch_foo.json \
       --owner root --group consul --mode 640 \
       --source "$__type/files/watch_foo.json" \
       --state present \
       --onchange 'service consul status >/dev/null && service consul reload || true'

## 16.21.6. SEE ALSO

cdist-type__file(7)

## 16.21.7. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.21.8. COPYING

Copyright (C) 2015 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.